@@ -36,6 +36,14 @@
 
 const char *cmd = "lvmiopversion";
 
+/* vgchange is the program we look for to determine that LVM is
+ * installed in that directory. This prevents the situation where
+ * (eg) LVM1 has a command that LVM2 doesn't and LVM2 is the currently
+ * running system. Under the old lvmiopversion, the LVM1 command
+ * would be run.
+ */
+const char *defcmd = "vgchange";
+
 int main(int argc, char *argv[])
 {
     struct stat st;
@@ -56,14 +64,14 @@ int main(int argc, char *argv[])
         return 0;
     }
 
-    snprintf(prog, sizeof(prog), "/lib/lvm-%d/%s", version, name);
+    snprintf(prog, sizeof(prog), "/lib/lvm-%d/%s", version, defcmd);
     if (stat(prog, &st) != 0 && version >= 200) {
         /* LVM2 kernel is loaded, but userspace is unavailable; try LVM1 */
         version = check_lvm1();
         if (version)
             snprintf(prog, sizeof(prog), "/lib/lvm-%d/%s", version, name);
     }
-    
+
     /* Let missing driver error messages come from the tools themselves */
     if (!version || stat(prog, &st) != 0)
         snprintf(prog, sizeof(prog), "/lib/lvm-default/%s", name);
@@ -73,7 +81,10 @@ int main(int argc, char *argv[])
         fprintf(stderr, "%s -- Unsupported LVM driver/module in kernel, please upgrade!\n\n", cmd);
         return LVM_EINVALID_IOP;
     }
- 
+
+    /* Now try for the real prog */
+    snprintf(prog, sizeof(prog), "/lib/lvm-%d/%s", version, name);
+
     /* and attempt to execute program.. */
     execv(prog, argv);
     if (errno == ENOENT) {
